==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/GridColumnAnimationSettingsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnAnimationSettingsDescription } from "./GridColumnAnimationSettingsDescription";
/**
 * @hidden
 */
export let GridColumnAnimationSettingsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnAnimationSettingsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnAnimationSettingsDescriptionMetadata.a == null) {
                GridColumnAnimationSettingsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnAnimationSettingsDescriptionMetadata.c(GridColumnAnimationSettingsDescriptionMetadata.a);
            }
            if (a.j(GridColumnAnimationSettingsDescriptionMetadata.a)) {
                return;
            }
            a.y(GridColumnAnimationSettingsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            GridColumnAnimationSettingsDescriptionMetadata.b(a);
            a.aa("GridColumnAnimationSettings", () => new GridColumnAnimationSettingsDescription());
            a.z("GridColumnAnimationSettings", GridColumnAnimationSettingsDescriptionMetadata.a);
        }
    }
    GridColumnAnimationSettingsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnAnimationSettingsDescriptionMetadata, 'GridColumnAnimationSettingsDescriptionMetadata');
    GridColumnAnimationSettingsDescriptionMetadata.a = null;
    return GridColumnAnimationSettingsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridColumnAnimationSettingsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnAnimationSettingsDescription } from "./GridColumnAnimationSettingsDescription";
/**
 * @hidden
 */
export let GridColumnAnimationSettingsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnAnimationSettingsDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnAnimationSettingsDescriptionMetadata.a == null) {
                GridColumnAnimationSettingsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnAnimationSettingsDescriptionMetadata.c(GridColumnAnimationSettingsDescriptionMetadata.a);
            }
            if (a.k(GridColumnAnimationSettingsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridColumnAnimationSettingsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            GridColumnAnimationSettingsDescriptionMetadata.b(a);
            a.ac("GridColumnAnimationSettings", () => new GridColumnAnimationSettingsDescription());
            a.ab("GridColumnAnimationSettings", GridColumnAnimationSettingsDescriptionMetadata.a);
        }
    }
    GridColumnAnimationSettingsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnAnimationSettingsDescriptionMetadata, 'GridColumnAnimationSettingsDescriptionMetadata');
    GridColumnAnimationSettingsDescriptionMetadata.a = null;
    return GridColumnAnimationSettingsDescriptionMetadata;
})();
